@@ -303,17 +303,17 @@ impl Operation {
             }
             Self::Function { func, field } => {
                 let func_ident = Ident::new(&func, Span::call_site());
-                match field {
-                    Some(field) => {
+                field.map_or(
+                    quote! {
+                        self.#func_ident(errors);
+                    },
+                    |field| {
                         let field_token = Self::field_token(&field, custom_token, false);
                         quote! {
                             Self::#func_ident(#field, &#field_token, errors);
                         }
-                    }
-                    None => quote! {
-                        self.#func_ident(errors);
                     },
-                }
+                )
             }
         }
     }
