@@ -1,5 +1,13 @@
 #![forbid(unsafe_code)]
-#![deny(warnings)]
+#![warn(
+    clippy::all,
+    clippy::correctness,
+    clippy::suspicious,
+    clippy::style,
+    clippy::complexity,
+    clippy::perf,
+    nonstandard_style
+)]
 
 extern crate proc_macro;
 extern crate proc_macro2;
